@@ -42,7 +42,7 @@ public:
     QFont font;
     KCharSelectItemModel *model = nullptr;
     QVector<uint> chars;
-    uint chr;
+    uint chr = 0;
 
     void resizeCells();
     void doubleClicked(const QModelIndex &index);
@@ -104,6 +104,8 @@ public:
     void linkClicked(QUrl url);
 };
 
+Q_DECLARE_TYPEINFO(KCharSelectPrivate::HistoryItem, Q_MOVABLE_TYPE);
+
 /******************************************************************/
 /* Class: KCharSelectTable                                        */
 /******************************************************************/
@@ -467,7 +469,6 @@ void KCharSelect::initWidget(const Controls controls, QObject *actionParent)
     d->blockCombo->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
     comboLayout->addWidget(d->blockCombo, 1);
     QStringList sectionList = s_data()->sectionList();
-    sectionList << QCoreApplication::translate("KCharSelectData", "All", "KCharSelect section name");
     d->sectionCombo->addItems(sectionList);
     d->blockCombo->setMinimumWidth(QFontMetrics(QWidget::font()).averageCharWidth() * 25);
 
