@@ -18,7 +18,7 @@
 class KCollapsibleGroupBoxPrivate
 {
 public:
-    KCollapsibleGroupBoxPrivate(KCollapsibleGroupBox *q);
+    KCollapsibleGroupBoxPrivate(KCollapsibleGroupBox *qq);
     void updateChildrenFocus(bool expanded);
     void recalculateHeaderSize();
     QSize contentSize() const;
@@ -34,8 +34,8 @@ public:
     QMap<QWidget *, Qt::FocusPolicy> focusMap; // Used to restore focus policy of widgets.
 };
 
-KCollapsibleGroupBoxPrivate::KCollapsibleGroupBoxPrivate(KCollapsibleGroupBox *q)
-    : q(q)
+KCollapsibleGroupBoxPrivate::KCollapsibleGroupBoxPrivate(KCollapsibleGroupBox *qq)
+    : q(qq)
 {
 }
 
@@ -208,7 +208,10 @@ bool KCollapsibleGroupBox::event(QEvent *event)
             // Needs to be called asynchronously because at this point the widget is likely a "real" QWidget,
             // i.e. the QWidget base class whose constructor sets the focus policy to NoPolicy.
             // But the constructor of the child class (not yet called) could set a different focus policy later.
-            QMetaObject::invokeMethod(this, "overrideFocusPolicyOf", Qt::QueuedConnection, Q_ARG(QWidget *, widget));
+            auto focusFunc = [this, widget]() {
+                overrideFocusPolicyOf(widget);
+            };
+            QMetaObject::invokeMethod(this, focusFunc, Qt::QueuedConnection);
         }
         break;
     }
@@ -281,17 +284,6 @@ void KCollapsibleGroupBox::resizeEvent(QResizeEvent *event)
 
 void KCollapsibleGroupBox::overrideFocusPolicyOf(QWidget *widget)
 {
-    // https://bugs.kde.org/show_bug.cgi?id=396450
-    // A label with word-wrapping enabled will break positioning of the groupbox in the layout.
-    // The cause seems to be the setFocusPolicy() call below, but it's not clear why.
-    // Until a proper fix is found, as workaround we toggle twice the groupbox which fixes the issue.
-    if (auto label = qobject_cast<QLabel *>(widget)) {
-        if (label->wordWrap()) {
-            toggle();
-            toggle();
-        }
-    }
-
     d->focusMap.insert(widget, widget->focusPolicy());
 
     if (!isExpanded()) {
@@ -347,3 +339,5 @@ QSize KCollapsibleGroupBoxPrivate::contentMinimumSize() const
     }
     return QSize(0, 0);
 }
+
+#include "moc_kcollapsiblegroupbox.cpp"
