@@ -19,11 +19,11 @@ class KColorComboDelegate : public QAbstractItemDelegate
     Q_OBJECT
 public:
     enum ItemRoles {
-        ColorRole = Qt::UserRole + 1
+        ColorRole = Qt::UserRole + 1,
     };
 
     enum LayoutMetrics {
-        FrameMargin = 3
+        FrameMargin = 3,
     };
 
     KColorComboDelegate(QObject *parent = nullptr);
@@ -99,7 +99,8 @@ void KColorComboDelegate::paint(QPainter *painter, const QStyleOptionViewItem &o
                 textColor = option.palette.color(QPalette::Text);
             }
         } else {
-            int unused, v;
+            int unused;
+            int v;
             innercolor.getHsv(&unused, &unused, &v);
             if (v > 128) {
                 textColor = Qt::black;
@@ -121,33 +122,33 @@ QSize KColorComboDelegate::sizeHint(const QStyleOptionViewItem &option, const QM
 }
 
 static const uchar standardPalette[][4] = {
-    { 255, 255, 255 }, // white
-    { 192, 192, 192 }, // light gray
-    { 160, 160, 160 }, // gray
-    { 128, 128, 128 }, // dark gray
-    { 0, 0, 0 }, // black
+    {255, 255, 255}, // white
+    {192, 192, 192}, // light gray
+    {160, 160, 160}, // gray
+    {128, 128, 128}, // dark gray
+    {0, 0, 0}, // black
 
-    { 255, 128, 128 }, //light red
-    { 255, 192, 128 }, //light orange
-    { 255, 255, 128 }, //light yellow
-    { 128, 255, 128 }, //light green
-    { 128, 255, 255 }, //cyan blue
-    { 128, 128, 255 }, //light blue
-    { 255, 128, 255 }, //light violet
-    { 255, 0, 0 }, //red
-    { 255, 128, 0 }, //orange
-    { 255, 255, 0 }, //yellow
-    { 0, 255, 0 }, //green
-    { 0, 255, 255 }, //light blue
-    { 0, 0, 255 }, //blue
-    { 255, 0, 255 }, //violet
-    { 128, 0, 0 }, //dark red
-    { 128, 64, 0 }, //dark orange
-    { 128, 128, 0 }, //dark yellow
-    { 0, 128, 0 }, //dark green
-    { 0, 128, 128 }, //dark light blue
-    { 0, 0, 128 }, //dark blue
-    { 128, 0, 128 } //dark violet
+    {255, 128, 128}, // light red
+    {255, 192, 128}, // light orange
+    {255, 255, 128}, // light yellow
+    {128, 255, 128}, // light green
+    {128, 255, 255}, // cyan blue
+    {128, 128, 255}, // light blue
+    {255, 128, 255}, // light violet
+    {255, 0, 0}, // red
+    {255, 128, 0}, // orange
+    {255, 255, 0}, // yellow
+    {0, 255, 0}, // green
+    {0, 255, 255}, // light blue
+    {0, 0, 255}, // blue
+    {255, 0, 255}, // violet
+    {128, 0, 0}, // dark red
+    {128, 64, 0}, // dark orange
+    {128, 128, 0}, // dark yellow
+    {0, 128, 0}, // dark green
+    {0, 128, 128}, // dark light blue
+    {0, 0, 128}, // dark blue
+    {128, 0, 128} // dark violet
 };
 
 #define STANDARD_PALETTE_SIZE (int(sizeof(standardPalette) / sizeof(*standardPalette)))
@@ -167,8 +168,8 @@ public:
     void setCustomColor(const QColor &color, bool lookupInPresets = true);
 
     // slots
-    void _k_slotActivated(int index);
-    void _k_slotHighlighted(int index);
+    void slotActivated(int index);
+    void slotHighlighted(int index);
 
     KColorCombo *q;
     QList<QColor> colorList;
@@ -177,7 +178,8 @@ public:
 };
 
 KColorComboPrivate::KColorComboPrivate(KColorCombo *qq)
-    : q(qq), customColor(Qt::white)
+    : q(qq)
+    , customColor(Qt::white)
 {
 }
 
@@ -208,25 +210,27 @@ void KColorComboPrivate::setCustomColor(const QColor &color, bool lookupInPreset
 }
 
 KColorCombo::KColorCombo(QWidget *parent)
-    : QComboBox(parent), d(new KColorComboPrivate(this))
+    : QComboBox(parent)
+    , d(new KColorComboPrivate(this))
 {
     setItemDelegate(new KColorComboDelegate(this));
     d->addColors();
 
-    connect(this, SIGNAL(activated(int)), SLOT(_k_slotActivated(int)));
-    connect(this, SIGNAL(highlighted(int)), SLOT(_k_slotHighlighted(int)));
+    connect(this, qOverload<int>(&QComboBox::activated), this, [this](int index) {
+        d->slotActivated(index);
+    });
+    connect(this, qOverload<int>(&QComboBox::highlighted), this, [this](int index) {
+        d->slotHighlighted(index);
+    });
 
     // select the white color
     setCurrentIndex(1);
-    d->_k_slotActivated(1);
+    d->slotActivated(1);
 
     setMaxVisibleItems(13);
 }
 
-KColorCombo::~KColorCombo()
-{
-    delete d;
-}
+KColorCombo::~KColorCombo() = default;
 
 void KColorCombo::setColors(const QList<QColor> &colors)
 {
@@ -294,7 +298,7 @@ void KColorCombo::showEmptyList()
     clear();
 }
 
-void KColorComboPrivate::_k_slotActivated(int index)
+void KColorComboPrivate::slotActivated(int index)
 {
     if (index == 0) {
         QColor c = QColorDialog::getColor(customColor, q);
@@ -308,10 +312,10 @@ void KColorComboPrivate::_k_slotActivated(int index)
         internalcolor = colorList[index - 1];
     }
 
-    emit q->activated(internalcolor);
+    Q_EMIT q->activated(internalcolor);
 }
 
-void KColorComboPrivate::_k_slotHighlighted(int index)
+void KColorComboPrivate::slotHighlighted(int index)
 {
     if (index == 0) {
         internalcolor = customColor;
@@ -321,7 +325,7 @@ void KColorComboPrivate::_k_slotHighlighted(int index)
         internalcolor = colorList[index - 1];
     }
 
-    emit q->highlighted(internalcolor);
+    Q_EMIT q->highlighted(internalcolor);
 }
 
 void KColorComboPrivate::addColors()
@@ -341,5 +345,5 @@ void KColorComboPrivate::addColors()
     }
 }
 
-#include "moc_kcolorcombo.cpp"
 #include "kcolorcombo.moc"
+#include "moc_kcolorcombo.cpp"
