@@ -16,14 +16,14 @@ class KPageWidgetPrivate : public KPageViewPrivate
 {
     Q_DECLARE_PUBLIC(KPageWidget)
 protected:
-    KPageWidgetPrivate(KPageWidget *q);
+    KPageWidgetPrivate(KPageWidget *qq);
 
     KPageWidgetModel *model() const
     {
         return static_cast<KPageWidgetModel *>(KPageViewPrivate::model);
     }
 
-    void _k_slotCurrentPageChanged(const QModelIndex &, const QModelIndex &);
+    void slotCurrentPageChanged(const QModelIndex &, const QModelIndex &);
 };
 
 #endif // KPAGEWIDGET_P_H
