@@ -1,21 +1,9 @@
 /* -*- c++ -*- */
-/* This file is part of the KDE libraries
-    Copyright (C) 1998 Jörg Habenicht (j.habenicht@europemail.com)
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1998 Jörg Habenicht <j.habenicht@europemail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KRULER_H
@@ -24,6 +12,7 @@
 #include <kwidgetsaddons_export.h>
 
 #include <QAbstractSlider>
+#include <memory>
 
 /**
  * @class KRuler kruler.h KRuler
@@ -84,7 +73,7 @@ class KWIDGETSADDONS_EXPORT KRuler : public QAbstractSlider
 public:
     /**
      * The types of units used.
-     **/
+     */
     enum MetricStyle { Custom = 0, Pixel, Inch, Millimetres, Centimetres, Metres };
     Q_ENUM(MetricStyle)
 
@@ -103,15 +92,15 @@ public:
      * @param parent     Will be handed over to QFrame.
      * @param f          Will be handed over to QFrame.
      *
-     **/
-    explicit KRuler(Qt::Orientation orient, QWidget *parent = nullptr, Qt::WindowFlags f = nullptr);
+     */
+    explicit KRuler(Qt::Orientation orient, QWidget *parent = nullptr, Qt::WindowFlags f = Qt::WindowFlags());
 
     /**
      * Constructs a ruler with orientation @p orient and initial width @p widgetWidth.
      *
      * The width sets the fixed width of the widget. This is useful if you
      * want to draw the ruler bigger or smaller than the default size.
-     * Note: The size of the marks doesn't change.
+     * @note The size of the marks doesn't change.
      * @p parent and @p f are passed to QFrame.
      *
      * @param orient      Orientation of the ruler.
@@ -120,47 +109,57 @@ public:
      * @param f           Will be handed over to QFrame.
      *
      */
-    KRuler(Qt::Orientation orient, int widgetWidth, QWidget *parent = nullptr,
-           Qt::WindowFlags f = nullptr);
+    KRuler(Qt::Orientation orient, int widgetWidth, QWidget *parent = nullptr, Qt::WindowFlags f = Qt::WindowFlags());
 
     /**
      * Destructor.
      */
-    ~KRuler();
+    ~KRuler() override;
 
+#if KWIDGETSADDONS_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * Sets the minimal value of the ruler pointer (default is 0).
      *
      * This method calls update() so that the widget is painted after leaving
      * to the main event loop.
      *
-     **/
-#ifndef KWIDGETSADDONS_NO_DEPRECATED
-    KWIDGETSADDONS_DEPRECATED void setMinValue(int);
+     * @deprecated Since 5.0, use setMinimum(int).
+     */
+    KWIDGETSADDONS_DEPRECATED_VERSION(5, 0, "Use KRuler::setMinimum(int)")
+    void setMinValue(int);
 #endif
 
+#if KWIDGETSADDONS_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * Returns the minimal value of the ruler pointer.
-     **/
-#ifndef KWIDGETSADDONS_NO_DEPRECATED
-    KWIDGETSADDONS_DEPRECATED int minValue() const;
+     *
+     * @deprecated Since 5.0, use minimum().
+     */
+    KWIDGETSADDONS_DEPRECATED_VERSION(5, 0, "Use KRuler::minimum()")
+    int minValue() const;
 #endif
 
+#if KWIDGETSADDONS_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * Sets the maximum value of the ruler pointer (default is 100).
      *
      * This method calls update() so that the widget is painted after leaving
      * to the main event loop.
+     *
+     * @deprecated Since 5.0, use setMaximum().
      */
-#ifndef KWIDGETSADDONS_NO_DEPRECATED
-    KWIDGETSADDONS_DEPRECATED void setMaxValue(int);
+    KWIDGETSADDONS_DEPRECATED_VERSION(5, 0, "Use KRuler::setMaximum(int)")
+    void setMaxValue(int);
 #endif
 
+#if KWIDGETSADDONS_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * Returns the maximal value of the ruler pointer.
+     *
+     * @deprecated Since 5.0, use maximum().
      */
-#ifndef KWIDGETSADDONS_NO_DEPRECATED
-    KWIDGETSADDONS_DEPRECATED int maxValue() const;
+    KWIDGETSADDONS_DEPRECATED_VERSION(5, 0, "Use KRuler::maximum()")
+    int maxValue() const;
 #endif
 
     /**
@@ -171,7 +170,7 @@ public:
     void setTinyMarkDistance(int);
     /**
      * Returns the distance between tiny marks.
-     **/
+     */
     int tinyMarkDistance() const;
 
     /**
@@ -191,7 +190,7 @@ public:
      *
      * For English (inches) styles it defaults to twice the little mark distance.
      * For metric styles it defaults to five times the little mark distance.
-     **/
+     */
     void setMediumMarkDistance(int);
     int mediumMarkDistance() const;
 
@@ -199,36 +198,36 @@ public:
      * Sets distance between big marks.
      *
      * For English (inches) or metric styles it is twice the medium mark distance.
-     **/
+     */
     void setBigMarkDistance(int);
     /**
      * Returns the distance between big marks.
-     **/
+     */
     int bigMarkDistance() const;
 
     /**
      * Shows/hides tiny marks.
-     **/
+     */
     void setShowTinyMarks(bool);
     bool showTinyMarks() const;
     /**
      * Shows/hides little marks.
-     **/
+     */
     void setShowLittleMarks(bool);
     bool showLittleMarks() const;
     /**
      * Shows/hides medium marks.
-     **/
+     */
     void setShowMediumMarks(bool);
     bool showMediumMarks() const;
     /**
      * Shows/hides big marks.
-     **/
+     */
     void setShowBigMarks(bool);
     bool showBigMarks() const;
     /**
      * Shows/hides end marks.
-     **/
+     */
     void setShowEndMarks(bool);
     bool showEndMarks() const;
     /**
@@ -237,22 +236,27 @@ public:
     void setShowPointer(bool);
     bool showPointer() const;
 
-#ifndef KWIDGETSADDONS_NO_DEPRECATED
-    KWIDGETSADDONS_DEPRECATED void setFrameStyle(int);
+#if KWIDGETSADDONS_ENABLE_DEPRECATED_SINCE(5, 0)
+    /**
+     * Is a no-op.
+     * @deprecated Since 5.0.
+     */
+    KWIDGETSADDONS_DEPRECATED_VERSION(5, 0, "No longer a feature")
+    void setFrameStyle(int);
 #endif
 
     /**
      * Show/hide number values of the end marks.
      *
      * Default is @p false.
-     **/
+     */
     void setShowEndLabel(bool);
     bool showEndLabel() const;
 
     /**
      * Sets the label this is drawn at the beginning of the visible part
      * of the ruler to @p label
-     **/
+     */
     void setEndLabel(const QString &);
     QString endLabel() const;
 
@@ -260,7 +264,7 @@ public:
      * Sets up the necessary tasks for the provided styles.
      *
      * A convenience method.
-     **/
+     */
     void setRulerMetricStyle(KRuler::MetricStyle);
 
     /**
@@ -285,7 +289,7 @@ public:
 
     /**
      * Returns the number of pixels between two base marks.
-     **/
+     */
     double pixelPerMark() const;
 
     /**
@@ -319,7 +323,7 @@ public:
      * Only the visible part of the ruler is moved.
      *
      * @param count Number of pixel moving up or left relative to the previous position
-     **/
+     */
     void slideUp(int count = 1);
 
     /**
@@ -332,7 +336,7 @@ public:
      * Only the visible part of the ruler is moved.
      *
      * @param count Number of pixel moving up or left relative to the previous position
-     **/
+     */
     void slideDown(int count = 1);
 
     /**
@@ -342,12 +346,12 @@ public:
      * from the start of the ruler.
      *
      * @param offset Number of pixel to move the ruler up or left from the beginning
-     **/
+     */
     void setOffset(int offset);
 
     /**
      * Returns the current ruler offset.
-     **/
+     */
     int offset() const;
 
     int endOffset() const;
@@ -359,7 +363,7 @@ public Q_SLOTS:
      *
      * The offset is NOT updated.
      * QWidget::repaint() is called afterwards.
-     **/
+     */
     void slotNewValue(int);
 
     /**
@@ -367,20 +371,19 @@ public Q_SLOTS:
      *
      * The pointer is NOT updated.
      * QWidget::repaint() is called afterwards.
-     **/
+     */
     void slotNewOffset(int);
 
     void slotEndOffset(int);
 
 protected:
-    void paintEvent(QPaintEvent *) Q_DECL_OVERRIDE;
+    void paintEvent(QPaintEvent *) override;
 
 private:
-    void initWidget(Qt::Orientation orientation);
+    KWIDGETSADDONS_NO_EXPORT void initWidget(Qt::Orientation orientation);
 
 private:
-    class KRulerPrivate;
-    KRulerPrivate *const d;
+    std::unique_ptr<class KRulerPrivate> const d;
 };
 
 #endif
